##############################################
Frequency Series (:mod:`gwpy.frequencyseries`)
##############################################

.. automodule:: gwpy.frequencyseries

.. seealso::

    - **User Guide**: :doc:`/spectrum/index`
    - **Examples**: :doc:`/examples/frequencyseries/index`

.. automodapi:: gwpy.frequencyseries
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
